@@ -2,6 +2,7 @@ extern crate proc_macro;
 
 use anchor_syn::codegen::error as error_codegen;
 use anchor_syn::parser::error as error_parser;
+use anchor_syn::ErrorArgs;
 use syn::parse_macro_input;
 
 /// Generates `Error` and `type Result<T> = Result<T, Error>` types to be
@@ -47,10 +48,14 @@ use syn::parse_macro_input;
 /// parsers  and IDLs can map error codes to error messages.
 #[proc_macro_attribute]
 pub fn error(
-    _args: proc_macro::TokenStream,
+    args: proc_macro::TokenStream,
     input: proc_macro::TokenStream,
 ) -> proc_macro::TokenStream {
+    let args = match args.is_empty() {
+        true => None,
+        false => Some(parse_macro_input!(args as ErrorArgs)),
+    };
     let mut error_enum = parse_macro_input!(input as syn::ItemEnum);
-    let error = error_codegen::generate(error_parser::parse(&mut error_enum));
+    let error = error_codegen::generate(error_parser::parse(&mut error_enum, args));
     proc_macro::TokenStream::from(error)
 }
